#!/usr/bin/env python3
#./2_find_motifs_in_promoters.py

import re
from Bio import SeqIO

def find_motif_frequency_and_distribution(fasta_file, output_file, motif_1="GRGGC", motif_2="GCCYR"):
    motif_1 = motif_1.replace("R", "[AG]").replace("Y", "[CT]")
    motif_2 = motif_2.replace("R", "[AG]").replace("Y", "[CT]")
    promoter_sequences = SeqIO.parse(fasta_file, "fasta")

    with open(output_file, 'w') as f:
        f.write("PromoterID\tGene_Symbol\tGene_Type\tMotif_GRGGC_Count\tMotif_GCCYR_Count\tMotif_GRGGC_Center_Positions\tMotif_GCCYR_Center_Positions\n")

        for promoter in promoter_sequences:
            header_parts = promoter.description.split("|")
            promoter_id = header_parts[0].strip()
            gene_symbol = header_parts[1].strip()
            gene_type = header_parts[2].strip()

            motif1_positions = [(m.start() + len(motif_1) // 2 - 3000) for m in re.finditer(motif_1, str(promoter.seq))]
            motif2_positions = [(m.start() + len(motif_2) // 2 - 3000) for m in re.finditer(motif_2, str(promoter.seq))]

            line = f"{promoter_id}\t{gene_symbol}\t{gene_type}\t{len(motif1_positions)}\t{len(motif2_positions)}\t{motif1_positions}\t{motif2_positions}\n"
            f.write(line)


if __name__ == "__main__":
    fasta_file = "promoter_sequences_3000_3000.fasta"
    output_file = "motif_counts_positions.txt"
    find_motif_frequency_and_distribution(fasta_file, output_file)
